@@ -12,6 +12,7 @@ async def unlock(
     profiles: Dict[str, Dict[str, Any]],
     backend_key: str = None,
     allowed_backend_profiles: List[str] = None,
+    hard_fail: bool = False,
 ):
     """
     Read the raw profiles and search for externally defined profiles.
@@ -46,6 +47,8 @@ async def unlock(
                 coros.append(hub.pop.loop.unwrap(backend_profiles))
             except Exception as e:
                 hub.log.error(f"{e.__class__}: {e}")
+                if hard_fail:
+                    raise
 
     # process all the backends simultaneously
     for result in asyncio.as_completed(coros):
@@ -54,5 +57,7 @@ async def unlock(
             dict_tools.update.update(ret, backend_profiles)
         except Exception as e:
             hub.log.error(f"{e.__class__}: {e}")
+            if hard_fail:
+                raise
 
     return ret
